==> jc-1.4.0.tar.gz: javax/xml/parsers/FactoryConfigurationError.h <==
// public class javax.xml.parsers.FactoryConfigurationError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a7739ce77632a9dd javax_xml_parsers_FactoryConfigurationError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_javax_xml_parsers_FactoryConfigurationError_H_
#define _JC_javax_xml_parsers_FactoryConfigurationError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$sub_refs	_jc_javax_xml_parsers_FactoryConfigurationError$sub_refs;
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$sub_nonrefs	_jc_javax_xml_parsers_FactoryConfigurationError$sub_nonrefs;
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$refs	_jc_javax_xml_parsers_FactoryConfigurationError$refs;
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$nonrefs	_jc_javax_xml_parsers_FactoryConfigurationError$nonrefs;
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$object	_jc_javax_xml_parsers_FactoryConfigurationError$object;

typedef const struct _jc_javax_xml_parsers_FactoryConfigurationError$vmethods	_jc_javax_xml_parsers_FactoryConfigurationError$vmethods;
typedef const struct _jc_javax_xml_parsers_FactoryConfigurationError$vtable	_jc_javax_xml_parsers_FactoryConfigurationError$vtable;
typedef const struct _jc_javax_xml_parsers_FactoryConfigurationError$vtype	_jc_javax_xml_parsers_FactoryConfigurationError$vtype;

// Constructors
extern void _jc_javax_xml_parsers_FactoryConfigurationError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *);
extern void _jc_javax_xml_parsers_FactoryConfigurationError$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *, struct _jc_java_lang_Exception$object *);
extern void _jc_javax_xml_parsers_FactoryConfigurationError$method$_init$82e384f63a3614a6(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *, struct _jc_java_lang_Exception$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_xml_parsers_FactoryConfigurationError$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Exception$object *_jc_javax_xml_parsers_FactoryConfigurationError$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *);
extern struct _jc_java_lang_String$object *_jc_javax_xml_parsers_FactoryConfigurationError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_xml_parsers_FactoryConfigurationError$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_javax_xml_parsers_FactoryConfigurationError$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_javax_xml_parsers_FactoryConfigurationError$vmethods {
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *);
};

// Vtable
struct _jc_javax_xml_parsers_FactoryConfigurationError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_javax_xml_parsers_FactoryConfigurationError$vmethods	javax_xml_parsers_FactoryConfigurationError;
};

// Vtype
struct _jc_javax_xml_parsers_FactoryConfigurationError$vtype {
	_jc_type			type;
	_jc_javax_xml_parsers_FactoryConfigurationError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_parsers_FactoryConfigurationError$sub_refs {
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_javax_xml_parsers_FactoryConfigurationError$refs {
    _jc_javax_xml_parsers_FactoryConfigurationError$sub_refs	javax_xml_parsers_FactoryConfigurationError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_parsers_FactoryConfigurationError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_parsers_FactoryConfigurationError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_javax_xml_parsers_FactoryConfigurationError$sub_nonrefs	javax_xml_parsers_FactoryConfigurationError;
};

// Object instance structure
struct _jc_javax_xml_parsers_FactoryConfigurationError$object {
	_jc_javax_xml_parsers_FactoryConfigurationError$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_parsers_FactoryConfigurationError$vtype	*vtype;
	_jc_javax_xml_parsers_FactoryConfigurationError$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_parsers_FactoryConfigurationError$vtype _jc_javax_xml_parsers_FactoryConfigurationError$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_parsers_FactoryConfigurationError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_parsers_FactoryConfigurationError$class_object;

#endif	/* _JC_javax_xml_parsers_FactoryConfigurationError_H_ */

==> jc-1.4.6.tar.gz: javax/xml/parsers/FactoryConfigurationError.h <==
// public class javax.xml.parsers.FactoryConfigurationError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a7739ce77632a9dd javax_xml_parsers_FactoryConfigurationError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_javax_xml_parsers_FactoryConfigurationError_H_
#define _JC_javax_xml_parsers_FactoryConfigurationError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$sub_refs	_jc_javax_xml_parsers_FactoryConfigurationError$sub_refs;
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$sub_nonrefs	_jc_javax_xml_parsers_FactoryConfigurationError$sub_nonrefs;
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$refs	_jc_javax_xml_parsers_FactoryConfigurationError$refs;
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$nonrefs	_jc_javax_xml_parsers_FactoryConfigurationError$nonrefs;
typedef struct _jc_javax_xml_parsers_FactoryConfigurationError$object	_jc_javax_xml_parsers_FactoryConfigurationError$object;

typedef const struct _jc_javax_xml_parsers_FactoryConfigurationError$vmethods	_jc_javax_xml_parsers_FactoryConfigurationError$vmethods;
typedef const struct _jc_javax_xml_parsers_FactoryConfigurationError$vtable	_jc_javax_xml_parsers_FactoryConfigurationError$vtable;
typedef const struct _jc_javax_xml_parsers_FactoryConfigurationError$vtype	_jc_javax_xml_parsers_FactoryConfigurationError$vtype;

// Constructors
extern void _jc_javax_xml_parsers_FactoryConfigurationError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_parsers_FactoryConfigurationError$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_parsers_FactoryConfigurationError$method$_init$82e384f63a3614a6(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *, struct _jc_java_lang_Exception$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_parsers_FactoryConfigurationError$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Exception$object *_jc_javax_xml_parsers_FactoryConfigurationError$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_xml_parsers_FactoryConfigurationError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_xml_parsers_FactoryConfigurationError$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_javax_xml_parsers_FactoryConfigurationError$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_javax_xml_parsers_FactoryConfigurationError$vmethods {
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_javax_xml_parsers_FactoryConfigurationError$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_xml_parsers_FactoryConfigurationError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_javax_xml_parsers_FactoryConfigurationError$vmethods	javax_xml_parsers_FactoryConfigurationError;
};

// Vtype
struct _jc_javax_xml_parsers_FactoryConfigurationError$vtype {
	_jc_type			type;
	_jc_javax_xml_parsers_FactoryConfigurationError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_parsers_FactoryConfigurationError$sub_refs {
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_javax_xml_parsers_FactoryConfigurationError$refs {
    _jc_javax_xml_parsers_FactoryConfigurationError$sub_refs	javax_xml_parsers_FactoryConfigurationError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_parsers_FactoryConfigurationError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_parsers_FactoryConfigurationError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_javax_xml_parsers_FactoryConfigurationError$sub_nonrefs	javax_xml_parsers_FactoryConfigurationError;
};

// Object instance structure
struct _jc_javax_xml_parsers_FactoryConfigurationError$object {
	_jc_javax_xml_parsers_FactoryConfigurationError$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_parsers_FactoryConfigurationError$vtype	*vtype;
	_jc_javax_xml_parsers_FactoryConfigurationError$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_parsers_FactoryConfigurationError$vtype _jc_javax_xml_parsers_FactoryConfigurationError$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_parsers_FactoryConfigurationError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_parsers_FactoryConfigurationError$class_object;

#endif	/* _JC_javax_xml_parsers_FactoryConfigurationError_H_ */
